import { FolderPath, FolderName, FileOrFolderPath, FilePath, FileName, RelativeOrAbsoluteFilePath, RelativeFilePath, RelativeOrAbsoluteFolderPath, FileOrFolderPathSortKey, FolderNameSuffixed, FolderPathSuffixed } from "../common/model/Primitives";
declare type AnyPath = FilePath | FolderPath | FileOrFolderPath | FileOrFolderPathSortKey;
/**
 * Extremely easy to make mistakes here, so be careful!
 *
 * (Fortunately we have unit tests for this class.)
 *
 * DO NOT USE Node's 'Path' object to perform the logic: these paths are S3-esque, so may contain "..", which may be
 * accidentally resolved if we use path libraries to do the parsing.
 */
export declare class FolderPathUtils {
    static readonly root: string & {
        readonly __TYPE__: "FolderPath";
    };
    private static readonly allSlashesRegex;
    static splitExtension(fileName: FileName): [string, string];
    static getFolderPathSortKey(folderPath: FolderPath): FileOrFolderPathSortKey;
    static getFolderPathSuffixed(folderPath: FolderPath): FolderPathSuffixed;
    static getFolderNameSuffixed(folderName: FolderName): FolderNameSuffixed;
    static combineRelativeMaybe(parentFolder: FolderPath | undefined, childPath: FilePath | RelativeOrAbsoluteFilePath | RelativeOrAbsoluteFolderPath): FileOrFolderPath;
    static isAbsolute(path: FilePath | RelativeOrAbsoluteFilePath | RelativeOrAbsoluteFolderPath): boolean;
    static isRelative(path: RelativeOrAbsoluteFilePath | RelativeOrAbsoluteFolderPath): boolean;
    static isDescendantOrEqual(root: FolderPath, descendant: AnyPath): boolean;
    static isDescendant(root: FolderPath, descendant: AnyPath): boolean;
    static isChildOrEqual(root: FolderPath, child: AnyPath): boolean;
    static isChild(root: FolderPath, child: AnyPath): boolean;
    /**
     * Gets the prefix that all descendants of this folder will have, that all non-descendants don't have.
     * Useful for translating folder paths to S3 prefixes.
     * Always ends with "/".
     */
    static getDescendantPrefix(parent: FolderPath): FolderPath;
    static getDescendantNameRelativeToRoot<T extends FolderName | FileName>(root: FolderPath, descendant: AnyPath): T;
    static combine(parentFolder: FolderPath | undefined, childName: RelativeFilePath | FolderName | FileName): FileOrFolderPath;
    static getFileName(filePath: FilePath): FileName;
    static getFolderName(folderPath: FolderPath): FolderName;
    static getName(folderPath: FolderPath | FilePath): FolderName | FileName;
    static rebasePath<T extends FolderPath | FilePath | FileOrFolderPath>(path: T, oldBase: FolderPath, newBase: FolderPath): T;
    static getParentFolderOrRoot(folderPath: FilePath | FolderPath | FileOrFolderPath): FolderPath;
    static getParentFolder(folderPath: AnyPath): FolderPath | undefined;
    /**
     * Returns in ascending order, e.g. "/", "/foo", "/foo/bar"
     */
    static getAncestors(folderPath: FilePath | FolderPath | FileOrFolderPath): FolderPath[];
    static allSlashes(value: string): boolean;
}
export {};
